summaryrefslogtreecommitdiff
path: root/sys/arch/mvme88k/dev/osiop_pcctwo.c
diff options
context:
space:
mode:
authorMiod Vallat <miod@cvs.openbsd.org>2006-05-08 14:36:11 +0000
committerMiod Vallat <miod@cvs.openbsd.org>2006-05-08 14:36:11 +0000
commit491bb53ae4e146b2682e22062a1ebf5064292f94 (patch)
treea9645db4291bbbc72840bbe42ba5a10b5cfe1167 /sys/arch/mvme88k/dev/osiop_pcctwo.c
parentc73c0e01b2fc454406e0c3138cb97706813c4876 (diff)
Replace gazillions of badvaddr() or badwordaddr() calls with badaddr() calls.
With a few prototype declarations shuffling, this finally allows <machine/locore.h> to die.
Diffstat (limited to 'sys/arch/mvme88k/dev/osiop_pcctwo.c')
-rw-r--r--sys/arch/mvme88k/dev/osiop_pcctwo.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/arch/mvme88k/dev/osiop_pcctwo.c b/sys/arch/mvme88k/dev/osiop_pcctwo.c
index 38d4dcfcea9..8f86767a82f 100644
--- a/sys/arch/mvme88k/dev/osiop_pcctwo.c
+++ b/sys/arch/mvme88k/dev/osiop_pcctwo.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: osiop_pcctwo.c,v 1.4 2006/04/15 22:29:49 miod Exp $ */
+/* $OpenBSD: osiop_pcctwo.c,v 1.5 2006/05/08 14:36:10 miod Exp $ */
/*
* Copyright (c) 2004, Miodrag Vallat.
*
@@ -69,7 +69,7 @@ osiop_pcctwo_match(struct device *parent, void *cf, void *aux)
if (bus_space_map(ca->ca_iot, ca->ca_paddr, OSIOP_NREGS, 0, &ioh) != 0)
return (0);
- rc = badvaddr((vaddr_t)bus_space_vaddr(ca->ca_iot, ioh), 4);
+ rc = badaddr((vaddr_t)bus_space_vaddr(ca->ca_iot, ioh), 4);
if (rc == 0) {
bus_space_unmap(ca->ca_iot, ioh, OSIOP_NREGS);
return (1);
@@ -77,7 +77,7 @@ osiop_pcctwo_match(struct device *parent, void *cf, void *aux)
/*
* For some reason, if the SCSI hardware is not ``warmed'' by the
* BUG (netboot or boot from external SCSI controller), badvaddr()
* will always fail, although the hardware is there.
* Since the BUG will do the right thing, we'll defer a dummy read
* from the controller and retry.
@@ -94,7 +94,7 @@ osiop_pcctwo_match(struct device *parent, void *cf, void *aux)
dio.blk_cnt = 1;
bugdiskrd(&dio);
- rc = badvaddr((vaddr_t)bus_space_vaddr(ca->ca_iot, ioh), 4);
+ rc = badaddr((vaddr_t)bus_space_vaddr(ca->ca_iot, ioh), 4);
}
bus_space_unmap(ca->ca_iot, ioh, OSIOP_NREGS);
@@ -77,7 +77,7 @@ osiop_pcctwo_match(struct device *parent, void *cf, void *aux)
/*
* For some reason, if the SCSI hardware is not ``warmed'' by the
- * BUG (netboot or boot from external SCSI controller), badvaddr()
+ * BUG (netboot or boot from external SCSI controller), badaddr()
* will always fail, although the hardware is there.
* Since the BUG will do the right thing, we'll defer a dummy read